<?php

namespace Database\Seeders;

use App\Models\User;
use Illuminate\Database\Console\Seeds\WithoutModelEvents;
use Illuminate\Database\Seeder;

class DatabaseSeeder extends Seeder
{
    /**
     * Seed the application's database.
     *
     * @return void
     */
    public function run()
    {
        User::create([
            'ref_by' => null,
            'position_id' => 0,
            'position' => 0,
            'rank' => 0,
            'plan_id' => 0,
            'firstname' => 'admin',
            'lastname' => 'eofap',
            'username' => 'admin',
            'email' => 'admin@eofap.in',
            'country_code' => 'IN',
            'mobile' => '0000000000',
            'balance' => '0.00000000',
            'image' => null,
            'address' => [
                'address' => 'some',
                'city' => 'some',
                'state' => 'some',
                'zip' => 'some',
                'country' => 'India',
            ],
            'status' => 1,
            'kyc_data' => null,
            'kv' => 1,
            'ev' => 1,
            'app_downloaded' => 0,
            'sv' => 1,
            'profile_complete' => 1,
            'ver_code_send_at' => null,
            'ts' => 0,
            'tv' => 1,
            'tsc' => null,
            'ban_reason' => null,
            'created_at' => '2024-10-22T15:30:40.000000Z',
            'updated_at' => '2024-10-22T16:19:30.000000Z',
            'dummy_person' => 1,
            'network_status' => 1,
            'network_activated_at' => null,
            'network_size' => 0,
            'active_network_size' => 0,
        ]);
    }
}
